### Reference information for data used in datalib
### adding something extra
| Material/Symbol      | Filename  |  Reference  | Trusted Wavelength Range
|---                     |---        |---          |---            | 
|Glass/SiO2 | SiO2_ir.txt | Two references are combined in a single file to provide refractive index data from 210 - 50000 nm: from 210 - 6700 nm, I. H. Malitson,  J. Opt. Soc. Am., "Interspecimen comparison of the refractive index of fused silica", 55, 1205-1208 (1965), and from 7000 - 50000 nm, S. Popova, T. Tolstykh, V. Vorobev, Opt. Spectrosc., "Optical characteristics of amorphous quartz in the 1400–200 cm-1 region", 33, 444–445 (1972) | 7000 - 500000 nm |
|Glass/SiO2_UDM | SiO2_udm.txt | Optical characterization of SiO2 thin films using universal dispersion model over wide spectral range,
Daniel Franta, David Nečas, Ivan Ohlídal, Angelo Giglia, Photonics Europe 2016: Optical Micro- and Nanometrology VI, Photonics Europe 2016: Optical Micro- and Nanometrology VI, Brussels, Belgium 3 - 7 April 2016 (2016) pp.989014 | 0.01 - 100 eV |
|Glass/SiO2_UDM_v2 | SiO2_udm_v2.txt | http://newad.physics.muni.cz/table-udm/LithosilQ2-SPIE9890.Enk | 0.01 - 100 eV |
|Tantalum Pentaoxide/Ta2O5 \ Ta2O5_Bright.txt | T. J. Bright, J. I. Watjen, Z. M. Zhang, C. Muratore, A. A. Voevodin, D. I. Koukis, D. B. Tanner and D. J. Arenas. Infrared optical properties of amorphous and nanocrystalline Ta2O5 thin films J. Appl. Phys 114, 083515 (2013) | TBD | 
|Titanium nitride/TiN | TiN_ellipsometry_data.txt | N. Jeoni et al., Adv. Energy Materials, "Pareto optimal spectrally selective emitters for thermophotovoltaics viaweak absorber critical coupling", 8, 1801035 (2018) | TBD |
|Titanium dioxide/TiO2 | TiO2_Siefke.txt | T. Siefke, S. Kroker, K. Pfeiffer, O. Puffky, K. Dietrich, D. Franta, I. Ohlídal, A. Szeghalmi, E.-B. Kley, A. Tünnermann, Adv. Opt. Mater., "Materials pushing the application limits of wire grid polarizers further into the deep ultraviolet spectral range", 4, 1780–1786 (2016) | TBD | 
|Polystyrene/PS| polystyrene.txt| 1) X. Zhang, J. Qiu, X. Li, J. Zhao, L. Liu. Complex refractive indices measurements of polymers in visible and near-infrared bands, Appl. Opt. 59, 2337-2344 (2020) (0.4-2 µm) | X. Zhang, J. Qiu, J. Zhao, X. Li, L. Liu. Complex refractive indices measurements of polymers in infrared bands, J. Quant. Spectrosc. Radiat. Transf. 252, 107063 (2020) (2-20 µm)| 2-20 microns |
|Silver/Ag|AG_Yang.txt| H. U. Yang, J. D'Archangel, M. L. Sundheimer, E. Tucker, G. D. Boreman, M. B. Raschke,  Phys. Rev. B, "Optical dielectric function of silver",  91, 235137 (2015) |Visible|P. B. Johnson and R. W. Christy, Phys. Rev. B, "Optical Constants of noble metals", 6, 4370 (1972)| visible to IR |
|Gold/Au|Au_ri.txt| P. B. Johnson and R. W. Christy, Phys. Rev. B, "Optical Constants of noble metals", 6, 4370 (1972)|IR|starts 1e-6| R. L. Olmon, B. Slovick, T. W. Johnson, D. Shelton, S.-H. Oh, G. D. Boreman, and M. B. Raschke.  Phys. Rev. B, "Optical dielectric function of gold", 86, 235147 (2012)| visible |
|Aluminium/Al	Al_Rakic.txt|-A. D. Rakić. Algorithm for the determination of intrinsic optical constants of metal films: application to aluminum, Appl. Opt. 34, 4755-4767 (1995)|0.000124-200 Micrometer|
|Tungsten/W|	W.txt|	M. A. Ordal, R. J. Bell, R. W. Alexander, L. A. Newquist, M. R. Querry. Optical properties of Al, Fe, Ti, Ta, W, and Mo at submillimeter wavelengths, Appl. Opt. 27, 1203-1209 (1988)|0.667-200 Micrometer|
|Aluminium nitride/AlN	|AlN_Kischkat.txt|-J. Kischkat, S. Peters, B. Gruska, M. Semtsiv, M. Chashnikova, M. Klinkmüller, O. Fedosenko, S. Machulik, A. Aleksandrova, G. Monastyrskyi, Y. Flores, and W. T. Masselink. Mid-infrared optical properties of thin films of aluminum oxide, titanium dioxide, silicon dioxide, aluminum nitride, and silicon nitride, Appl. Opt. 51, 6789-6798 (2012) (Numerical data kindly provided by Jan Kischkat)|1.54-14.29 Micrometer|
|Aluminium oxide/Al2O3_UDM  |Al2O3_udm.txt | Optical characterization of SiO2 thin films using universal dispersion model over wide spectral range,
Daniel Franta, David Nečas, Ivan Ohlídal, Angelo Giglia, Photonics Europe 2016: Optical Micro- and Nanometrology VI, Photonics Europe 2016: Optical Micro- and Nanometrology VI, Brussels, Belgium 3 - 7 April 2016 (2016) pp.989014 | 0.01 - 100 eV |
|Hafnium dioxide/HfO2|HfO2.txt||M. F. Al-Kuhaili. Optical properties of hafnium oxide thin films and their application in energy-efficient windows. Opt. Mat. 27, 383-387 (2004)|0.2-2 micrometers|
|Hafnium dioxide/HfO2_udm| HfO2_udm.txt | http://newad.physics.muni.cz/table-udm/HfO2-X2194-AO54_9108.Enk | 0.01 - 100 eV |
|Platinum/Pt | Pt_txt | A. D. Rakić, A. B. Djurišic, J. M. Elazar, and M. L. Majewski. Optical properties of metallic films for vertical-cavity optoelectronic devices, Appl. Opt. 37, 5271-5283 (1998) | TBD |
|Lead/Pb | Pb_Werner.txt | W. S. M. Werner, K. Glantschnig, C. Ambrosch-Draxl. Optical constants and inelastic electron-scattering data for 17 elemental metals, J. Phys Chem Ref. Data 38, 1013-1092 (2009) | TBD |
|Rhenium/Re| Re_txt | E. D. Palik, "Handbook of optical constants of solids" (Academic Press, 1998) | TBD |
|Zirconia/ZrO2|ZrO2_Wood.txt | D. L Wood and K. Nassau. Refractive index of cubic zirconia stabilized with yttria, Appl. Opt. 21, 2978-2981 (1982) | 0.361-5.14 microns |
|Silicon Nitride/Si3N4| Si3N4_Luke.txt | K. Luke, Y. Okawachi, M. R. E. Lamont, A. L. Gaeta, M. Lipson. Broadband mid-infrared frequency comb generation in a Si3N4 microresonator, Opt. Lett. 40, 4823-4826 (2015) | 0.310–5.504 µm |
|2D Hybrid organic-inorganic perovskite | 2D_HOIP.txt | Song et al. "Determinatino of dielectric functions and exciton oscillator strength of two-dimensional hybrid perovskites", ACS Materials Lett. 2021, 3, 1, 148–159 | 0.371-1.69 µm |
|Magnesium Fluoride/MgF2 | MgF2_udm.txt | http://newad.physics.muni.cz/table-udm/MgF2-X2935-SPIE9628.Enk | 0.01 - 100 eV |
